Stan Math Library: stan/math/rev/scal/fun/log1p.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log1p.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_LOG1P_HPP
2 #define STAN_MATH_REV_SCAL_FUN_LOG1P_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <stan/math/prim/scal/fun/constants.hpp>
6 #include <stan/math/prim/scal/fun/log1p.hpp>
7 #include <valarray>
8
9 namespace stan {
10 namespace math {
11
12 namespace {
13 class log1p_vari : public op_v_vari {
14 public:
15 explicit log1p_vari(vari* avi) :
16 op_v_vari(stan::math::log1p(avi->val_), avi) {
17 }
18 void chain() {
19 avi_->adj_ += adj_ / (1 + avi_->val_);
20 }
21 };
22 }
23
34 inline var log1p(const stan::math::var& a) {
35 return var(new log1p_vari(a.vi_));
36 }
37
38 }
39 }
40 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43
constants.hpp
stan::math::log1p
fvar< T > log1p(const fvar< T > &x)
Definition: log1p.hpp:16
log1p.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.